#ifndef TEXTURED_POLYHEDRON_TYPE_H 
#define TEXTURED_POLYHEDRON_TYPE_H

#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
#include <CGAL/textured_polyhedron.h>

#include "Textured_polyhedron_type_fwd.h"

struct EPIC_kernel : public CGAL::Exact_predicates_inexact_constructions_kernel {};

#endif // TEXTURED_POLYHEDRON_TYPE_H
